@@ -1,16 +1,11 @@
+use std::io::{self, Write};
+
 use mysql::{Conn, Opts};
 
-use crate::{
-    configuration::config_model::GenericConfiguration,
-    databases::{generic::schema::read_schema, my_sql::insert},
-    name_generator::{
+use crate::{configuration::config_model::GenericConfiguration, databases::{generic::schema::read_schema, my_sql::insert}, date_generator::datetime::generate_datetime, name_generator::{
         loader::{loader, name_generator_exists},
         name::generate_name,
-    },
-    number_generator::number::{generate_int_number, int_generator_exists},
-    random_number,
-    string_generator::strings::generate_alphas,
-};
+    }, number_generator::number::{generate_int_number, int_generator_exists}, random_number, string_generator::strings::generate_alphas};
 
 use super::discover::ForeignKeyRel;
 
@@ -28,7 +23,7 @@ struct TempKeys {
     table_name: String,
 }
 
-pub fn spawn(config: &GenericConfiguration, schema_name: String, no_of_record: i32) {
+pub fn spawn(config: &GenericConfiguration, no_of_record: i32) {
     let url = format!(
         "mysql://{}:{}@{}:{}/{}",
         &config.mysql_configuration.user,
@@ -51,10 +46,13 @@ pub fn spawn(config: &GenericConfiguration, schema_name: String, no_of_record: i
         }
     };
 
-    let schema = read_schema(&mut connection, schema_name);
+    let schema = read_schema(&mut connection, config.clone().mysql_configuration.schema);
 
     let mut temp_keys: Vec<TempKeys> = vec![];
     for table in schema {
+        println!("");
+        println!("* Generating records for {:?}", &table.table_name);
+
         let mut columns: Vec<CdDt> = table
             .clone()
             .fields
@@ -83,11 +81,11 @@ pub fn spawn(config: &GenericConfiguration, schema_name: String, no_of_record: i
             .collect();
 
         columns.sort_by(|a, b| a.fk.cmp(&b.fk));
-
-        println!("{:?}", columns);
-
         let mut fk_keys: Vec<i32> = vec![];
         for _i in 0..no_of_record {
+            print!("*");
+            io::stdout().flush();
+
             let mut values: Vec<String> = vec![];
             let mut fk_table_data;
             for cd in &columns {
@@ -107,6 +105,13 @@ pub fn spawn(config: &GenericConfiguration, schema_name: String, no_of_record: i
                             "'{}'",
                             random_number!(i32)(0, 2147483647).to_string()
                         ));
+                    } else if cd.data_type.eq("datetime"){
+                        values.push(format!(
+                            "'{}'",
+                            generate_datetime()
+                        ));
+                    } else {
+                        println!("type {} not currently supported", cd.data_type);
                     }
                 } else {
                     let fk_table = cd.clone().dep.unwrap().referenced_table_name;
